# black-disable-checker

[![PyPI version](https://badge.fury.io/py/black-disable-checker.svg)](https://badge.fury.io/py/black-disable-checker)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)

> That little door knob on your blackened bike shed can also be any color you like; as
> long as it's black.

`black-disable-checker` is an uncompromising black adoption checker. By using it, you
agree to really cede control over minutiae of hand-formatting. In return, you will not
have to argue about disabling black or not. You will save time and mental energy for
more important matters.

## Installation

```yaml
- repo: https://github.com/Pierre-Sassoulas/black-disable-checker/
  rev: 1.1.3
  hooks:
    - id: black-disable-checker
```
